function varargout = simpleGUIPlot(varargin)
% SIMPLEGUIPLOT MATLAB code for simpleGUIPlot.fig
%      SIMPLEGUIPLOT, by itself, creates a new SIMPLEGUIPLOT or raises the existing
%      singleton*.
%
%      H = SIMPLEGUIPLOT returns the handle to a new SIMPLEGUIPLOT or the handle to
%      the existing singleton*.
%
%      SIMPLEGUIPLOT('CALLBACK',hObject,eventData,handles,...) calls the local
%      function named CALLBACK in SIMPLEGUIPLOT.M with the given input arguments.
%
%      SIMPLEGUIPLOT('Property','Value',...) creates a new SIMPLEGUIPLOT or raises the
%      existing singleton*.  Starting from the left, property value pairs are
%      applied to the GUI before simpleGUIPlot_OpeningFcn gets called.  An
%      unrecognized property name or invalid value makes property application
%      stop.  All inputs are passed to simpleGUIPlot_OpeningFcn via varargin.
%
%      *See GUI Options on GUIDE's Tools menu.  Choose "GUI allows only one
%      instance to run (singleton)".
%
% See also: GUIDE, GUIDATA, GUIHANDLES

% Edit the above text to modify the response to help simpleGUIPlot

% Last Modified by GUIDE v2.5 28-Jan-2013 20:58:08

% Begin initialization code - DO NOT EDIT
gui_Singleton = 1;
gui_State = struct('gui_Name',       mfilename, ...
                   'gui_Singleton',  gui_Singleton, ...
                   'gui_OpeningFcn', @simpleGUIPlot_OpeningFcn, ...
                   'gui_OutputFcn',  @simpleGUIPlot_OutputFcn, ...
                   'gui_LayoutFcn',  [] , ...
                   'gui_Callback',   []);
if nargin && ischar(varargin{1})
    gui_State.gui_Callback = str2func(varargin{1});
end

if nargout
    [varargout{1:nargout}] = gui_mainfcn(gui_State, varargin{:});
else
    gui_mainfcn(gui_State, varargin{:});
end
% End initialization code - DO NOT EDIT


% --- Executes just before simpleGUIPlot is made visible.
function simpleGUIPlot_OpeningFcn(hObject, eventdata, handles, varargin)
% This function has no output args, see OutputFcn.
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
% varargin   command line arguments to simpleGUIPlot (see VARARGIN)
opengl software

% Choose default command line output for simpleGUIPlot
handles.output = hObject;

% Update handles structure
guidata(hObject, handles);

% UIWAIT makes simpleGUIPlot wait for user response (see UIRESUME)
% uiwait(handles.figure1);


% --- Outputs from this function are returned to the command line.
function varargout = simpleGUIPlot_OutputFcn(hObject, eventdata, handles) 
% varargout  cell array for returning output args (see VARARGOUT);
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Get default command line output from handles structure
varargout{1} = handles.output;


% --- Executes on button press in plotButton.
function plotButton_Callback(hObject, eventdata, handles)
% hObject    handle to plotButton (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
[Z,R] = arcgridread('C:\\Genes profile\\Documents\\GIS\\MatlabData\\mc_3mbathy.grd');
mapshow(Z,R,'DisplayType', 'surface')


% --- Executes on button press in meterGuiButton.
function meterGuiButton_Callback(hObject, eventdata, handles)
% hObject    handle to meterGuiButton (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

h = meterGui;
meterGUIHandles = guihandles(h);
set(meterGUIHandles.meterRange2SCMPA, 'String', datestr(now));
